@@ -10,6 +10,7 @@ import (
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
+	"github.com/jandedobbeleer/oh-my-posh/src/text"
 )
 
 const (
@@ -48,7 +49,7 @@ func (s *ScmStatus) Changed() bool {
 }
 
 func (s *ScmStatus) String() string {
-	var status strings.Builder
+	status := text.NewBuilder()
 
 	if s.Formats == nil {
 		s.Formats = make(map[string]string)
@@ -82,8 +83,8 @@ func (s *ScmStatus) String() string {
 	return strings.TrimSpace(status.String())
 }
 
-type scm struct {
-	base
+type Scm struct {
+	Base
 
 	Dir             string
 	RepoName        string
@@ -101,7 +102,7 @@ const (
 	BranchTemplate properties.Property = "branch_template"
 )
 
-func (s *scm) RelativeDir() string {
+func (s *Scm) RelativeDir() string {
 	if s.repoRootDir == "" {
 		return ""
 	}
@@ -122,7 +123,7 @@ func (s *scm) RelativeDir() string {
 	return rel
 }
 
-func (s *scm) formatBranch(branch string) string {
+func (s *Scm) formatBranch(branch string) string {
 	mappedBranches := s.props.GetKeyValueMap(MappedBranches, make(map[string]string))
 
 	// sort the keys alphabetically
@@ -161,24 +162,19 @@ func (s *scm) formatBranch(branch string) string {
 		return branch
 	}
 
-	tmpl := &template.Text{
-		Template: branchTemplate,
-		Context:  struct{ Branch string }{Branch: branch},
-	}
-
-	text, err := tmpl.Render()
+	txt, err := template.Render(branchTemplate, struct{ Branch string }{Branch: branch})
 	if err != nil {
 		return branch
 	}
 
-	return text
+	return txt
 }
 
-func (s *scm) fileContent(folder, file string) string {
+func (s *Scm) fileContent(folder, file string) string {
 	return strings.Trim(s.env.FileContent(folder+"/"+file), " \r\n")
 }
 
-func (s *scm) convertToWindowsPath(path string) string {
+func (s *Scm) convertToWindowsPath(path string) string {
 	// only convert when in Windows, or when in a WSL shared folder and not using the native fallback
 	if s.env.GOOS() == runtime.WINDOWS || (s.IsWslSharedPath && !s.nativeFallback) {
 		return s.env.ConvertToWindowsPath(path)
@@ -187,7 +183,7 @@ func (s *scm) convertToWindowsPath(path string) string {
 	return path
 }
 
-func (s *scm) convertToLinuxPath(path string) string {
+func (s *Scm) convertToLinuxPath(path string) string {
 	if !s.IsWslSharedPath {
 		return path
 	}
@@ -195,7 +191,7 @@ func (s *scm) convertToLinuxPath(path string) string {
 	return s.env.ConvertToLinuxPath(path)
 }
 
-func (s *scm) hasCommand(command string) bool {
+func (s *Scm) hasCommand(command string) bool {
 	if len(s.command) > 0 {
 		return true
 	}
